==> ukui-power-manager_3.1.0.orig.tar.gz: ukui-power-manager/ukui-power-manager-tray/translations/ukui-power-manager-tray_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DeviceForm</name>
    <message>
        <source>RemainTime</source>
        <translation type="vanished">预计剩余时间</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <source>RemainTime</source>
        <translation type="vanished">预计剩余时间</translation>
    </message>
</context>
<context>
    <name>EngineDevice</name>
    <message>
        <location filename="../enginedevice.cpp" line="214"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="214"/>
        <source>no</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="249"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="249"/>
        <source>No</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="628"/>
        <source>Unknown time</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="634"/>
        <location filename="../enginedevice.cpp" line="655"/>
        <source>minute</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="636"/>
        <location filename="../enginedevice.cpp" line="657"/>
        <source>minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="647"/>
        <location filename="../enginedevice.cpp" line="659"/>
        <source>hour</source>
        <translation>小时</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="649"/>
        <location filename="../enginedevice.cpp" line="661"/>
        <source>hours</source>
        <translation>小时</translation>
    </message>
    <message>
        <source>fully charged</source>
        <translation type="vanished">已充满</translation>
    </message>
    <message>
        <source>not charging</source>
        <translation type="vanished">未充电</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="708"/>
        <source>%1% available, charged</source>
        <translation>%1%可用，已充满</translation>
    </message>
    <message>
        <source>%1% available, not charging</source>
        <translation type="vanished">%1%可用，未充电</translation>
    </message>
    <message>
        <source>%1% available, charging</source>
        <translation type="vanished">%1%可用，正在充电</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="726"/>
        <source>%1 waiting to discharge (%2%)</source>
        <translation>%1 等待放电 (%2%)</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="732"/>
        <source>%1 waiting to charge (%2%)</source>
        <translation>%1 等待充电 (%2%)</translation>
    </message>
    <message>
        <source>discharging(%1%)</source>
        <translation type="vanished">放电(%1%)</translation>
    </message>
    <message>
        <source>charging(%1%)</source>
        <translation type="vanished">充电(%1%)</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="796"/>
        <source>AC adapter</source>
        <translation>交流电源适配器</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="800"/>
        <source>Laptop battery</source>
        <translation>笔记本电池</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="804"/>
        <source>UPS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="808"/>
        <source>Monitor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="812"/>
        <source>Mouse</source>
        <translation>鼠标</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="816"/>
        <source>Keyboard</source>
        <translation>键盘</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="820"/>
        <source>PDA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="824"/>
        <source>Cell phone</source>
        <translation>手机</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="828"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="832"/>
        <source>Tablet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="836"/>
        <source>Computer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="840"/>
        <source>unrecognised</source>
        <translation>未识别</translation>
    </message>
    <message>
        <source>charging</source>
        <translation type="vanished">正在充电</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="712"/>
        <source>Left %1h %2m (%3%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="718"/>
        <source>Left %1h %2m to full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="720"/>
        <source>charging (%1%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>discharging</source>
        <translation type="vanished">放电</translation>
    </message>
    <message>
        <source>empty</source>
        <translation type="vanished">电量空</translation>
    </message>
    <message>
        <source>fully</source>
        <translation type="vanished">电量满</translation>
    </message>
    <message>
        <source>other</source>
        <translation type="vanished">其他</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>SetPower</source>
        <translation>设置电源和睡眠</translation>
    </message>
    <message>
        <source>ShowPercentage</source>
        <translation type="vanished">显示百分比</translation>
    </message>
    <message>
        <source>SetBrightness</source>
        <translation type="vanished">调整亮度</translation>
    </message>
    <message>
        <source>discharge notify notification</source>
        <translation type="vanished">正在放电</translation>
    </message>
    <message>
        <source>battery is discharging!</source>
        <translation type="vanished">电池正在放电</translation>
    </message>
    <message>
        <source>fullly charged notification</source>
        <translation type="vanished">电池充满</translation>
    </message>
    <message>
        <source>battery is fullly charged!</source>
        <translation type="vanished">电池已经充满</translation>
    </message>
    <message>
        <source>low battery notification</source>
        <translation type="vanished">电量低</translation>
    </message>
    <message>
        <source>battery is low,please plug in!</source>
        <translation type="vanished">电量低，请充电</translation>
    </message>
    <message>
        <source>critical battery notification</source>
        <translation type="vanished">电量很低</translation>
    </message>
    <message>
        <source>battery is critical low,please plug in!</source>
        <translation type="vanished">电量很低，请充电</translation>
    </message>
    <message>
        <source>very low battery notification</source>
        <translation type="vanished">电量非常低</translation>
    </message>
    <message>
        <source>battery is very low,please plug in!</source>
        <translation type="vanished">电量即将耗尽！</translation>
    </message>
    <message>
        <source>PowerManagement</source>
        <translation type="vanished">电源管理</translation>
    </message>
    <message>
        <source>Stats</source>
        <oldsource>Statistics</oldsource>
        <translation type="vanished">电源统计</translation>
    </message>
    <message>
        <source>PowerManager</source>
        <translation type="vanished">电源管理</translation>
    </message>
    <message>
        <source>PowerStatistics</source>
        <translation type="vanished">电源统计</translation>
    </message>
    <message>
        <source>PowerSaveMode</source>
        <translation type="vanished">省电模式</translation>
    </message>
    <message>
        <source>BatterySave</source>
        <translation type="vanished">电池养护</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation type="vanished">亮度</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="enginedevice.cpp" line="583"/>
        <source></source>
        <comment>tablet device</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>powerwindow</name>
    <message>
        <location filename="../powerwindow.cpp" line="78"/>
        <source>Charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="81"/>
        <source>fully charged</source>
        <translation type="unfinished">已充满</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="252"/>
        <source>Left %1h %2m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PowerManagement</source>
        <translation type="obsolete">电源管理</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="329"/>
        <location filename="../powerwindow.cpp" line="348"/>
        <location filename="../powerwindow.cpp" line="383"/>
        <location filename="../powerwindow.cpp" line="403"/>
        <location filename="../powerwindow.cpp" line="422"/>
        <location filename="../powerwindow.cpp" line="441"/>
        <source>Power Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="332"/>
        <source>charge notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="333"/>
        <source>battery is charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="351"/>
        <source>discharged notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="352"/>
        <source>battery is discharging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="387"/>
        <source>fullly charged notification</source>
        <translation type="unfinished">电池充满</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="388"/>
        <source>battery is fullly charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="406"/>
        <source>low battery notification</source>
        <translation type="unfinished">电量低</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="407"/>
        <source>battery is low, please plug in power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="425"/>
        <source>critical battery notification</source>
        <translation type="unfinished">电量很低</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="426"/>
        <source>battery is critical low,please plug in!</source>
        <translation type="unfinished">电量很低，请充电</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="444"/>
        <source>operation notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="445"/>
        <source>performing low power operation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>settinglabel</name>
    <message>
        <location filename="../powerwindow.cpp" line="789"/>
        <source>PowerSet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-power-manager_3.1.1.orig.tar.gz: ukui-power-manager/ukui-power-manager-tray/translations/ukui-power-manager-tray_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DeviceForm</name>
    <message>
        <source>RemainTime</source>
        <translation type="vanished">预计剩余时间</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <source>RemainTime</source>
        <translation type="vanished">预计剩余时间</translation>
    </message>
</context>
<context>
    <name>EngineDevice</name>
    <message>
        <location filename="../enginedevice.cpp" line="111"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="111"/>
        <source>no</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="146"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="146"/>
        <source>No</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="524"/>
        <source>Unknown time</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="530"/>
        <location filename="../enginedevice.cpp" line="551"/>
        <source>minute</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="532"/>
        <location filename="../enginedevice.cpp" line="553"/>
        <source>minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="543"/>
        <location filename="../enginedevice.cpp" line="555"/>
        <source>hour</source>
        <translation>小时</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="545"/>
        <location filename="../enginedevice.cpp" line="557"/>
        <source>hours</source>
        <translation>小时</translation>
    </message>
    <message>
        <source>fully charged</source>
        <translation type="vanished">已充满</translation>
    </message>
    <message>
        <source>not charging</source>
        <translation type="vanished">未充电</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="604"/>
        <source>%1% available, charged</source>
        <translation>%1%可用，已充满</translation>
    </message>
    <message>
        <source>%1% available, not charging</source>
        <translation type="vanished">%1%可用，未充电</translation>
    </message>
    <message>
        <source>%1% available, charging</source>
        <translation type="vanished">%1%可用，正在充电</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="629"/>
        <source>%1 waiting to discharge (%2%)</source>
        <translation>%1 等待放电 (%2%)</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="635"/>
        <source>%1 waiting to charge (%2%)</source>
        <translation>%1 等待充电 (%2%)</translation>
    </message>
    <message>
        <source>discharging(%1%)</source>
        <translation type="vanished">放电(%1%)</translation>
    </message>
    <message>
        <source>charging(%1%)</source>
        <translation type="vanished">充电(%1%)</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="699"/>
        <source>AC adapter</source>
        <translation>交流电源适配器</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="703"/>
        <source>Laptop battery</source>
        <translation>笔记本电池</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="707"/>
        <source>UPS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="711"/>
        <source>Monitor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="715"/>
        <source>Mouse</source>
        <translation>鼠标</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="719"/>
        <source>Keyboard</source>
        <translation>键盘</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="723"/>
        <source>PDA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="727"/>
        <source>Cell phone</source>
        <translation>手机</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="731"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="735"/>
        <source>Tablet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="739"/>
        <source>Computer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="743"/>
        <source>unrecognised</source>
        <translation>未识别</translation>
    </message>
    <message>
        <source>charging</source>
        <translation type="vanished">正在充电</translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="610"/>
        <source>Left %1h %2m (%3%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="612"/>
        <source>%1% available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="621"/>
        <source>Left %1h %2m to full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="623"/>
        <source>charging (%1%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>discharging</source>
        <translation type="vanished">放电</translation>
    </message>
    <message>
        <source>empty</source>
        <translation type="vanished">电量空</translation>
    </message>
    <message>
        <source>fully</source>
        <translation type="vanished">电量满</translation>
    </message>
    <message>
        <source>other</source>
        <translation type="vanished">其他</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>SetPower</source>
        <translation type="vanished">设置电源和睡眠</translation>
    </message>
    <message>
        <source>ShowPercentage</source>
        <translation type="vanished">显示百分比</translation>
    </message>
    <message>
        <source>SetBrightness</source>
        <translation type="vanished">调整亮度</translation>
    </message>
    <message>
        <source>discharge notify notification</source>
        <translation type="vanished">正在放电</translation>
    </message>
    <message>
        <source>battery is discharging!</source>
        <translation type="vanished">电池正在放电</translation>
    </message>
    <message>
        <source>fullly charged notification</source>
        <translation type="vanished">电池充满</translation>
    </message>
    <message>
        <source>battery is fullly charged!</source>
        <translation type="vanished">电池已经充满</translation>
    </message>
    <message>
        <source>low battery notification</source>
        <translation type="vanished">电量低</translation>
    </message>
    <message>
        <source>battery is low,please plug in!</source>
        <translation type="vanished">电量低，请充电</translation>
    </message>
    <message>
        <source>critical battery notification</source>
        <translation type="vanished">电量很低</translation>
    </message>
    <message>
        <source>battery is critical low,please plug in!</source>
        <translation type="vanished">电量很低，请充电</translation>
    </message>
    <message>
        <source>very low battery notification</source>
        <translation type="vanished">电量非常低</translation>
    </message>
    <message>
        <source>battery is very low,please plug in!</source>
        <translation type="vanished">电量即将耗尽！</translation>
    </message>
    <message>
        <source>PowerManagement</source>
        <translation type="vanished">电源管理</translation>
    </message>
    <message>
        <source>Stats</source>
        <oldsource>Statistics</oldsource>
        <translation type="vanished">电源统计</translation>
    </message>
    <message>
        <source>PowerManager</source>
        <translation type="vanished">电源管理</translation>
    </message>
    <message>
        <source>PowerStatistics</source>
        <translation type="vanished">电源统计</translation>
    </message>
    <message>
        <source>PowerSaveMode</source>
        <translation type="vanished">省电模式</translation>
    </message>
    <message>
        <source>BatterySave</source>
        <translation type="vanished">电池养护</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation type="vanished">亮度</translation>
    </message>
</context>
<context>
    <name>PowerTray</name>
    <message>
        <location filename="../powertray.cpp" line="111"/>
        <source>SetPower</source>
        <translation type="unfinished">设置电源和睡眠</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="enginedevice.cpp" line="583"/>
        <source></source>
        <comment>tablet device</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>powerwindow</name>
    <message>
        <location filename="../powerwindow.cpp" line="134"/>
        <location filename="../powerwindow.cpp" line="267"/>
        <source>Charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="262"/>
        <source>Left %1h 
 %2m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="264"/>
        <source>Discharging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="270"/>
        <source>fully charged</source>
        <translation type="unfinished">已充满</translation>
    </message>
    <message>
        <source>PowerManagement</source>
        <translation type="obsolete">电源管理</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="298"/>
        <location filename="../powerwindow.cpp" line="312"/>
        <location filename="../powerwindow.cpp" line="326"/>
        <location filename="../powerwindow.cpp" line="343"/>
        <location filename="../powerwindow.cpp" line="357"/>
        <location filename="../powerwindow.cpp" line="372"/>
        <source>Power Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="298"/>
        <source>charge notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="299"/>
        <source>battery is charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="312"/>
        <source>discharged notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="313"/>
        <source>battery is discharging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="329"/>
        <source>fullly charged notification</source>
        <translation type="unfinished">电池充满</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="329"/>
        <source>battery is fullly charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="343"/>
        <source>low battery notification</source>
        <translation type="unfinished">电量低</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="344"/>
        <source>battery is low, please plug in power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="358"/>
        <source>critical battery notification</source>
        <translation type="unfinished">电量很低</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="358"/>
        <source>battery is critical low,please plug in!</source>
        <translation type="unfinished">电量很低，请充电</translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="372"/>
        <source>operation notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="373"/>
        <source>performing low power operation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>settinglabel</name>
    <message>
        <location filename="../powerwindow.cpp" line="511"/>
        <source>PowerSet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
